pub fn to_string<T>(value: &T) -> Result<String, Error>where T: Serialize,
Serialise the given data structure as a String of Nix data
Serialization can fail if the implemenatation of Serialize for T fails.
Serialize
T